@@ -13,6 +13,7 @@ import mns_common.component.em.em_stock_info_api as em_stock_info_api
 from mns_common.db.MongodbUtil import MongodbUtil
 import mns_common.constant.db_name_constant as db_name_constant
 import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
+from datetime import datetime
 
 mongodb_util = MongodbUtil('27017')
 
@@ -166,20 +167,30 @@ def sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_em_df, period, symbol, st
         stock_gdfx_free_top_10_em_df['str_day'] = str_day
 
         stock_gdfx_free_top_10_em_df['symbol'] = symbol
+
+        stock_gdfx_free_top_10_em_df['shares_number_str'] = stock_gdfx_free_top_10_em_df['shares_number'].astype(str)
+
         stock_gdfx_free_top_10_em_df[
-            '_id'] = symbol + '_' + period + '_' + stock_gdfx_free_top_10_em_df.shareholder_name
+            '_id'] = symbol + '_' + period + '_' + stock_gdfx_free_top_10_em_df.shares_number_str
         stock_gdfx_free_top_10_em_df['period'] = period
 
         query_exist = {'symbol': symbol, 'period': period}
         exist_df = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_FREE_TOP_10, query_exist)
+        now_date = datetime.now()
+        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
         # 不存在的时候更新创建时间
         if exist_df.shape[0] == 0:
             stock_gdfx_free_top_10_em_df['create_day'] = str_day
+            stock_gdfx_free_top_10_em_df['sync_time'] = str_now_date
         else:
             if 'create_day' in exist_df.columns:
                 stock_gdfx_free_top_10_em_df['create_day'] = list(exist_df['create_day'])[0]
             else:
                 stock_gdfx_free_top_10_em_df['create_day'] = str_day
+            if 'sync_time' in exist_df.columns:
+                stock_gdfx_free_top_10_em_df['sync_time'] = list(exist_df['sync_time'])[0]
+            else:
+                stock_gdfx_free_top_10_em_df['sync_time'] = str_now_date
         mongodb_util.save_mongo(stock_gdfx_free_top_10_em_df, db_name_constant.STOCK_GDFX_FREE_TOP_10)
 
 
@@ -188,19 +199,34 @@ def sync_stock_gdfx_top_10(stock_gdfx_top_10_em_df, period, symbol, str_day):
     if stock_gdfx_top_10_em_df is not None and stock_gdfx_top_10_em_df.shape[0] > 0:
         stock_gdfx_top_10_em_df['str_day'] = str_day
         stock_gdfx_top_10_em_df['symbol'] = symbol
-        stock_gdfx_top_10_em_df['_id'] = symbol + '_' + period + '_' + stock_gdfx_top_10_em_df.shareholder_name
+
+        stock_gdfx_top_10_em_df['shares_number_str'] = stock_gdfx_top_10_em_df['shares_number'].astype(str)
+
+        stock_gdfx_top_10_em_df['_id'] = symbol + '_' + period + '_' + stock_gdfx_top_10_em_df.shares_number_str
         stock_gdfx_top_10_em_df['period'] = period
 
         query_exist = {'symbol': symbol, 'period': period}
         exist_df = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_TOP_10, query_exist)
+        now_date = datetime.now()
+        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
+
         # 不存在的时候更新创建时间
         if exist_df.shape[0] == 0:
             stock_gdfx_top_10_em_df['create_day'] = str_day
+            stock_gdfx_top_10_em_df['sync_time'] = str_now_date
         else:
             if 'create_day' in exist_df.columns:
                 stock_gdfx_top_10_em_df['create_day'] = list(exist_df['create_day'])[0]
+
+
             else:
                 stock_gdfx_top_10_em_df['create_day'] = str_day
+
+            if 'sync_time' in exist_df.columns:
+                stock_gdfx_top_10_em_df['sync_time'] = list(exist_df['sync_time'])[0]
+            else:
+                stock_gdfx_top_10_em_df['sync_time'] = str_now_date
+
         mongodb_util.save_mongo(stock_gdfx_top_10_em_df, db_name_constant.STOCK_GDFX_TOP_10)
 
 
@@ -212,15 +238,15 @@ def sync_stock_gdfx_free_top_10_one_day(str_day):
     for real_time_one in real_time_quotes.itertuples():
         try:
             get_stock_gdfx_free_top_10_em(str_day, real_time_one.symbol)
+            logger.info('同步股票前十大流通东:{},{}', real_time_one.symbol, real_time_one.name)
         except BaseException as e:
             logger.error('同步所有股票前十大流通股本异常:{},{}', real_time_one.symbol, e)
     logger.info('同步所有股票股东列表完成:{}', str_day)
 
 
-from datetime import datetime
-
 if __name__ == '__main__':
-    now_date = datetime.now()
-    str_day_test = now_date.strftime('%Y-%m-%d')
+    get_stock_gdfx_free_top_10_em('20250930', '300697')
+    now_date_test = datetime.now()
+    str_day_test = now_date_test.strftime('%Y-%m-%d')
     logger.info('同步所有股票前十大流通股本')
     sync_stock_gdfx_free_top_10_one_day(str_day_test)
