@@ -9,6 +9,7 @@ sys.path.append(project_path)
 import pandas as pd
 import mns_common.utils.data_frame_util as data_frame_util
 import mns_common.api.kpl.common.kpl_common_field_constant as kpl_common_field_constant
+from loguru import logger
 
 BEST_CHOOSE = '7'
 AREA = '6'
@@ -117,7 +118,41 @@ def get_plate_index_his(index, index_type, str_day, begin, end):
     return data_df_his
 
 
+# 获取开盘啦 股票入选概念原因
+def get_kpl_concept_choose_reason(plate_id, symbol_list_str):
+    try:
+        response = requests.get(
+            url="https://apphwshhq.longhuvip.com/w1/api/index.php",
+            params={
+                "PhoneOSNew": "2",
+                "PlateID": plate_id,
+                "Stocks": symbol_list_str,
+                "VerSion": "5.21.0.3",
+                "a": "PlateIntroduction_Info",
+                "apiv": "w42",
+                "c": "ZhiShuRanking"
+            },
+            headers={
+                "User-Agent": "lhb/5.21.3 (com.kaipanla.www; build:0; iOS 18.6.2) Alamofire/4.9.1"
+            }
+        )
+
+        json_result = response.json()
+        symbol_list_reason = json_result.get('List')
+
+        df_simple = pd.DataFrame(symbol_list_reason, columns=['symbol', 'choose_reason', 'flag', 'remark'])
+        return df_simple
+    except BaseException as e:
+        logger.error("获取开盘啦股票入选原因异常:{},{},{}", plate_id, symbol_list_str, e)
+        return pd.DataFrame()
+
+
 if __name__ == '__main__':
+    plate_id_test = '801133'
+    symbol_list_str_test = "002017,002104,301678,003040,300689,300608,300698,600941,002313,002881,002467,300579,002355,300205,300638,002049"
+
+    df_simple_test = get_kpl_concept_choose_reason(plate_id_test, symbol_list_str_test)
+
     df = plate_detail_info('801359')
 
     df = get_plate_index(7)
