@@ -140,7 +140,8 @@ def convert_statistics(stat):
 # 获取实时行情涨停列表
 def get_real_time_zt_info():
     real_time_df = em_real_time_quotes_api.get_real_time_quotes_now(None, None)
-    real_time_df_zt = real_time_df.loc[real_time_df['chg'] > common_service_fun_api.ZT_CHG]
+    real_time_df_zt = real_time_df.loc[
+        (real_time_df['chg'] > common_service_fun_api.ZT_CHG) | (real_time_df['wei_bi'] == 100)]
     if data_frame_util.is_empty(real_time_df_zt):
         return pd.DataFrame()
     real_time_df_zt = real_time_df_zt[[
@@ -197,24 +198,83 @@ def get_now_zt_pool_with_reason(str_day):
     real_time_zt_df = get_real_time_zt_info()
     # 昨日涨停列表
     last_trade_zt = zt_common_service_api.get_last_trade_day_zt(str_day)
-    # 东方财富涨停列表
-    em_now_zt_pool = stock_zt_pool_api.stock_em_zt_pool_df(date_handle_util.no_slash_date(str_day))
+
+    try:
+        # 东方财富涨停列表
+        em_now_zt_pool = stock_zt_pool_api.stock_em_zt_pool_df(date_handle_util.no_slash_date(str_day))
+    except BaseException as e:
+        em_now_zt_pool = pd.DataFrame()
+        logger.error("获取东方财富涨停列表异常:{}", e)
+
     if data_frame_util.is_not_empty(em_now_zt_pool):
         real_time_zt_df_wei_bi_100 = real_time_zt_df.loc[real_time_zt_df['symbol'].isin(em_now_zt_pool['symbol'])]
         real_time_zt_df_high_chg = real_time_zt_df.loc[~(real_time_zt_df['symbol'].isin(em_now_zt_pool['symbol']))]
+
+        em_now_zt_pool = em_now_zt_pool[['symbol',
+                                         'connected_boards_numbers',
+                                         'statistics',
+                                         'closure_funds',
+                                         'first_closure_time',
+                                         'last_closure_time',
+                                         'frying_plates_numbers']]
+
+        em_now_zt_pool = em_now_zt_pool.set_index(['symbol'], drop=True)
+        real_time_zt_df_wei_bi_100 = real_time_zt_df_wei_bi_100.set_index(['symbol'], drop=False)
+        real_time_zt_df_wei_bi_100 = pd.merge(real_time_zt_df_wei_bi_100, em_now_zt_pool, how='outer',
+                                              left_index=True, right_index=True)
+
+        now_continue_zt = last_trade_zt.loc[
+            last_trade_zt['symbol'].isin(list(real_time_zt_df_wei_bi_100['symbol']))]
+
     else:
-        real_time_zt_df_high_chg = real_time_zt_df
+        real_time_zt_df_wei_bi_100 = real_time_zt_df.loc[real_time_zt_df['wei_bi'] == 100]
 
-    em_now_zt_pool = em_now_zt_pool[
-        ['symbol', 'connected_boards_numbers',
-         'statistics', 'closure_funds', 'first_closure_time',
-         'last_closure_time', 'frying_plates_numbers']]
+        real_time_zt_df_wei_bi_100['connected_boards_numbers'] = 1
+        real_time_zt_df_wei_bi_100['statistics'] = '1/1'
+        real_time_zt_df_wei_bi_100['closure_funds'] = real_time_zt_df_wei_bi_100['now_price'] * \
+                                                      real_time_zt_df_wei_bi_100['buy_1_num'] * 100
+        real_time_zt_df_wei_bi_100['first_closure_time'] = '153000'
+        real_time_zt_df_wei_bi_100['last_closure_time'] = '153000'
+        real_time_zt_df_wei_bi_100['frying_plates_numbers'] = 0
+        now_continue_zt = last_trade_zt.loc[
+            last_trade_zt['symbol'].isin(list(real_time_zt_df_wei_bi_100['symbol']))]
 
-    em_now_zt_pool = em_now_zt_pool.set_index(['symbol'], drop=True)
-    real_time_zt_df_wei_bi_100 = real_time_zt_df_wei_bi_100.set_index(['symbol'], drop=False)
-    real_time_zt_df_wei_bi_100 = pd.merge(real_time_zt_df_wei_bi_100, em_now_zt_pool, how='outer',
-                                          left_index=True, right_index=True)
+        if data_frame_util.is_not_empty(now_continue_zt):
+            now_continue_zt = now_continue_zt[['symbol', 'connected_boards_numbers', 'statistics']]
 
+            connected_boards_map = now_continue_zt.set_index('symbol')['connected_boards_numbers'].to_dict()
+
+            # 将映射的值加到原DataFrame上
+            real_time_zt_df_wei_bi_100['connected_boards_numbers'] = real_time_zt_df_wei_bi_100[
+                                                                         'connected_boards_numbers'] + \
+                                                                     real_time_zt_df_wei_bi_100['symbol'].map(
+                                                                         connected_boards_map).fillna(0)
+
+            real_time_zt_df_wei_bi_100 = real_time_zt_df_wei_bi_100.sort_values(by=['connected_boards_numbers'],
+                                                                                ascending=False)
+
+        real_time_zt_df_high_chg = real_time_zt_df.loc[real_time_zt_df['wei_bi'] != 100]
+
+        # todo
+    # 高涨幅处理
+    now_zt_pool_df = handle_high_chg(real_time_zt_df_high_chg, last_trade_zt, real_time_zt_df_wei_bi_100)
+
+    now_zt_pool_df = merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt, now_continue_zt)
+
+    result_first = now_zt_pool_df.loc[now_zt_pool_df['connected_boards_numbers'] == 1]
+    result_connected_boards = now_zt_pool_df.loc[now_zt_pool_df['connected_boards_numbers'] > 1]
+    result_connected_boards = result_connected_boards.sort_values(by=['connected_boards_numbers'], ascending=False)
+    result_first = result_first.sort_values(by=['first_closure_time'], ascending=True)
+
+    now_zt_pool_df = pd.concat([result_connected_boards,
+                                result_first])
+    now_zt_pool_df = now_zt_pool_df.fillna('未知数据')
+    now_zt_pool_df.drop_duplicates('symbol', keep='last', inplace=True)
+
+    return now_zt_pool_df
+
+
+def handle_high_chg(real_time_zt_df_high_chg, last_trade_zt, real_time_zt_df_wei_bi_100):
     # 初始化数据
     real_time_zt_df_high_chg['closure_funds'] = 0
     real_time_zt_df_high_chg['first_closure_time'] = '153000'
@@ -228,6 +288,7 @@ def get_now_zt_pool_with_reason(str_day):
 
     last_trade_zt_copy_today_high_chg = last_trade_zt.loc[
         last_trade_zt['symbol'].isin(real_time_zt_df_high_chg_last_trade_zt['symbol'])]
+
     last_trade_zt_copy_today_high_chg = last_trade_zt_copy_today_high_chg[
         ['symbol', 'connected_boards_numbers', 'statistics']]
     last_trade_zt_copy_today_high_chg['connected_boards_numbers'] = last_trade_zt_copy_today_high_chg[
@@ -247,21 +308,10 @@ def get_now_zt_pool_with_reason(str_day):
                                 real_time_zt_df_high_chg_last_trade_zt,
                                 real_time_zt_df_high_chg_last_trade_no_zt])
 
-    now_zt_pool_df = merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt)
-
-    result_first = now_zt_pool_df.loc[now_zt_pool_df['connected_boards_numbers'] == 1]
-    result_connected_boards = now_zt_pool_df.loc[now_zt_pool_df['connected_boards_numbers'] > 1]
-    result_connected_boards = result_connected_boards.sort_values(by=['connected_boards_numbers'], ascending=False)
-    result_first = result_first.sort_values(by=['first_closure_time'], ascending=True)
-
-    now_zt_pool_df = pd.concat([result_connected_boards,
-                                result_first])
-    now_zt_pool_df = now_zt_pool_df.fillna('未知数据')
-    now_zt_pool_df.drop_duplicates('symbol', keep='last', inplace=True)
     return now_zt_pool_df
 
 
-def merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt):
+def merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt, now_continue_zt):
     try:
         zt_reason_df = get_ths_stock_zt_reason_with_cache(str_day)
     except BaseException as e:
@@ -269,9 +319,14 @@ def merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt):
         logger.error("获取涨停原因异常:{}", e)
 
     last_trade_zt_copy = last_trade_zt.copy()
+
     if "zt_reason" not in last_trade_zt.columns:
         last_trade_zt_copy['zt_reason'] = '暂无'
-    last_trade_zt_copy = last_trade_zt_copy[['symbol', 'zt_reason']]
+
+    if 'main_line' not in last_trade_zt.columns:
+        last_trade_zt['main_line'] = ''
+
+    last_trade_zt_copy = last_trade_zt_copy[['symbol', 'zt_reason', 'main_line']]
 
     if data_frame_util.is_empty(zt_reason_df):
         now_zt_pool_df['zt_reason'] = '暂无'
@@ -289,6 +344,15 @@ def merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt):
     zt_reason_df_copy = zt_reason_df_copy.set_index(['symbol'], drop=True)
     now_zt_pool_df = now_zt_pool_df.set_index(['symbol'], drop=False)
 
+    if data_frame_util.is_not_empty(now_continue_zt):
+        now_continue_zt = now_continue_zt[['symbol', 'main_line']]
+
+        # 创建一个 symbol 到 main_line 的映射
+        main_line_mapping = now_continue_zt.set_index('symbol')['main_line'].to_dict()
+
+        # 使用 map 更新 main_line 列
+        now_zt_pool_df['main_line'] = now_zt_pool_df['symbol'].map(main_line_mapping).fillna("")
+
     result_zt_df = pd.merge(now_zt_pool_df, zt_reason_df_copy, how='outer',
                             left_index=True, right_index=True)
 
@@ -299,8 +363,10 @@ def merge_zt_reason(now_zt_pool_df, str_day, last_trade_zt):
     last_trade_zt_copy = last_trade_zt_copy.set_index(['symbol'], drop=True)
     del zt_reason_na['zt_reason']
     zt_reason_na = zt_reason_na.set_index(['symbol'], drop=False)
+    del last_trade_zt_copy['main_line']
     zt_reason_na = pd.merge(zt_reason_na, last_trade_zt_copy, how='outer',
                             left_index=True, right_index=True)
+
     zt_reason_na['zt_reason'] = zt_reason_na['zt_reason'].fillna('0')
     # 删除昨日涨停 今日未涨停的
     zt_reason_na.dropna(subset=['symbol'], inplace=True)
@@ -363,12 +429,11 @@ def zt_reason_group(zt_pool_df):
 
 
 if __name__ == '__main__':
-    str_day_test = '2024-10-09'
-
+    str_day_test = '2025-10-28'
+    # 同花顺涨停
+    ths_zt_pool_df = get_now_zt_pool_with_reason(str_day_test)
     # 东财涨停池
     em_now_zt_pool_test = stock_zt_pool_api.stock_em_zt_pool_df(date_handle_util.no_slash_date(str_day_test))
-    # 同花顺涨停
-    ths_zt_pool_df = get_zt_reason(str_day_test)
 
     miss_zt_df = em_now_zt_pool_test.loc[~(em_now_zt_pool_test['symbol'].isin(ths_zt_pool_df['symbol']))]
     pass
