@@ -31,7 +31,7 @@ def query_liu_guan_proxy_ip():
     return ip_proxy_pool
 
 
-def remove_proxy_ip():
+def remove_one_proxy_ip():
     mongodb_util.remove_data(query_one, db_name_constant.IP_PROXY_POOL)
 
 
@@ -42,7 +42,7 @@ def check_valid(ip_proxy_pool):
     if effect_time > str_now_date:
         return True
     else:
-        remove_proxy_ip()
+        remove_one_proxy_ip()
         return False
 
 
@@ -60,41 +60,41 @@ def generate_proxy_ip_api(minutes):
             order_id = list(stock_account_info['password'])[0]
             secret = list(stock_account_info['account'])[0]
             # 获取10分钟动态ip
-            ip = liu_guan_proxy_api.get_proxy_api(order_id, secret, str(60 * minutes))
-            try_numer = try_numer - 1
-            return ip
+            liu_guan_ip = liu_guan_proxy_api.get_proxy_api(order_id, secret, str(60 * minutes))
+            try_numer = try_numer
+            logger.info("生成新的ip:{}", liu_guan_ip)
+            return liu_guan_ip
         except BaseException as e:
+            logger.error("获取ip失败:{}", str(e))
             time.sleep(1)
             continue
 
 
 def generate_proxy_ip(minutes):
-    ip_proxy_pool = mongodb_util.find_all_data(db_name_constant.IP_PROXY_POOL)
+    ip_proxy_pool = query_liu_guan_proxy_ip()
     if data_frame_util.is_not_empty(ip_proxy_pool):
         return list(ip_proxy_pool['ip'])[0]
     else:
-        remove_proxy_ip()
+        remove_one_proxy_ip()
         now_date = datetime.datetime.now()
         # 加上分钟
         time_to_add = datetime.timedelta(minutes=minutes)
         new_date = now_date + time_to_add
         str_now_date = new_date.strftime('%Y-%m-%d %H:%M:%S')
-        # 获取10分钟动态ip
-        while True:
-            remove_proxy_ip()
-            ip = generate_proxy_ip_api(minutes)
-            if check_proxy(ip):
-                result_dict = {"_id": ip,
-                               'ip_type': ONE_IP,
-                               'effect_time': str_now_date,
-                               'ip': ip}
-                result_df = pd.DataFrame(result_dict, index=[1])
+        try:
+            ip_proxy = generate_proxy_ip_api(minutes)
 
-                mongodb_util.insert_mongo(result_df, db_name_constant.IP_PROXY_POOL)
-                break
-            else:
-                time.sleep(0.5)
-        return ip
+            result_dict = {"_id": ip_proxy,
+                           'ip_type': ONE_IP,
+                           'effect_time': str_now_date,
+                           'ip': ip_proxy}
+            result_df = pd.DataFrame(result_dict, index=[1])
+
+            mongodb_util.insert_mongo(result_df, db_name_constant.IP_PROXY_POOL)
+        except BaseException as e:
+            logger.error("获取ip失败:{}", str(e))
+
+        return ip_proxy
 
 
 def get_proxy_ip(minutes):
@@ -108,18 +108,19 @@ def get_proxy_ip(minutes):
             return generate_proxy_ip(minutes)
 
 
-def check_proxy(proxy_ip):
-    try:
-        # 两秒超时
-        test_df = call_with_timeout(get_em_real_time_data, proxy_ip, timeout=2)
-        if data_frame_util.is_not_empty(test_df):
-            logger.info("可用代理ip:{}", proxy_ip)
-            return True
-        else:
-            return False
-    except Exception as e:
-        logger.error("代理ip不可用:{},{}", proxy_ip, e)
-        return False
+#
+# def check_proxy(proxy_ip):
+#     try:
+#         # 两秒超时
+#         test_df = call_with_timeout(get_em_real_time_data, proxy_ip, timeout=2)
+#         if data_frame_util.is_not_empty(test_df):
+#             logger.info("可用代理ip:{}", proxy_ip)
+#             return True
+#         else:
+#             return False
+#     except Exception as e:
+#         logger.error("代理ip不可用:{},{}", proxy_ip, e)
+#         return False
 
 
 # 查询ip池子
@@ -194,7 +195,7 @@ def get_em_real_time_data(proxy_ip):
         "http": proxy_ip,
         "https": proxy_ip
     }
-    return east_money_stock_a_api.get_stock_page_data(1, proxies, 20)
+    return east_money_stock_a_api.get_stock_page_data(1, proxies, 20, 10)
 
 
 # 定义一个带超时的函数调用
@@ -244,5 +245,8 @@ def import_province_and_city():
 
 
 if __name__ == "__main__":
-    import_province_and_city()
-    # get_proxy_ip_pool(1, 50, 2)
+    stock_account_info_test = get_account_cache()
+    order_id_test = list(stock_account_info_test['password'])[0]
+    secret_test = list(stock_account_info_test['account'])[0]
+    # 获取10分钟动态ip
+    ip = liu_guan_proxy_api.get_proxy_api(order_id_test, secret_test, str(60 * 1))
